# -*- coding: utf-8 -*-

import os
import json
from collections import Counter
from datetime import datetime, timedelta

import pandas as pd

from ydl_ai_recommender.src.utils.log import create_logger
from ydl_ai_recommender.src.core.manager import DatabaseDataManager


class OrderDataManager(DatabaseDataManager):
    def __init__(self, client=None) -> None:
        super().__init__(client, create_logger(__name__, 'order_data_manager.log'))
        self.now = datetime.now()

    def _make_query_sql(self, conditions=None):
        condition_sql = ''
        if conditions:
            condition_sql = ' WHERE ' + ' AND '.join(conditions)

        select_fields = ['main_order_id', 'uid', 'supplier_id', 'price', 'standard_order_type']
        select_fields.append('DATE_FORMAT(update_time, "%Y-%m-%d") AS update_time')
        sql = 'SELECT {} FROM ods.ods_ydl_standard_order'.format(', '.join(select_fields))
        sql += condition_sql
        return sql

    def update_data(self):
        """ 从数据库中拉取最新订单数据并保存 """
        sql = self._make_query_sql()
        _, all_data = self.fetch_data_from_db(sql)

        df = pd.DataFrame(all_data)
        self.save_xlsx_data(df, 'all_order_info.xlsx')


    def update_test_data(self, conditions):
        """ 从数据库中拉取指定条件订单用于测试 """

        sql = self._make_query_sql(conditions)
        _, all_data = self.fetch_data_from_db(sql)

        df = pd.DataFrame(all_data)
        self.save_xlsx_data(df, 'test_order_info.xlsx')


    def load_raw_data(self):
        return self.load_xlsx_data('all_order_info.xlsx')


    def load_test_order_data(self):
        return self.load_xlsx_data('test_order_info.xlsx')


if __name__ == '__main__':
    manager = OrderDataManager()
    print(manager.make_index())